"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LokiJsConnection = void 0;
const lokijs_1 = __importDefault(require("lokijs"));
const LokiJsCollectionProvider_1 = require("./LokiJsCollectionProvider");
class LokiJsConnection {
    folder;
    databaseFactory;
    lokiJsOptions;
    providers;
    static defaultDatabaseFactory = {
        create: (filename, options) => {
            return new lokijs_1.default(filename, options);
        }
    };
    constructor(folder, databaseFactory = LokiJsConnection.defaultDatabaseFactory, lokiJsOptions = {}) {
        this.folder = folder;
        this.databaseFactory = databaseFactory;
        this.lokiJsOptions = lokiJsOptions;
        this.providers = new Map();
    }
    static fileSystem(folder, lokiJsOptions) {
        return new LokiJsConnection(folder, this.defaultDatabaseFactory, { ...lokiJsOptions, persistenceMethod: "fs" });
    }
    static localStorage(lokiJsOptions) {
        return new LokiJsConnection("", this.defaultDatabaseFactory, {
            ...lokiJsOptions,
            persistenceMethod: "localStorage"
        });
    }
    static inMemory(lokiJsOptions) {
        return new LokiJsConnection("", this.defaultDatabaseFactory, { ...lokiJsOptions, persistenceMethod: "memory" });
    }
    onCollectionClosed(name) {
        this.providers.delete(name);
    }
    async getDatabase(name) {
        const givenProvider = this.providers.get(name);
        if (givenProvider) {
            return givenProvider;
        }
        const that = this;
        return await new Promise((resolve) => {
            const db = this.databaseFactory.create(`${this.folder}/${name}.db`, {
                ...this.lokiJsOptions,
                autoload: true,
                autosave: true,
                autosaveInterval: 5000,
                autoloadCallback: () => {
                    const provider = new LokiJsCollectionProvider_1.LokiJsCollectionProvider(db, () => that.onCollectionClosed(name));
                    that.providers.set(name, provider);
                    resolve(provider);
                }
            });
        });
    }
    async closeAllProviders() {
        const openProviders = Array.from(this.providers.values());
        const closingPromises = openProviders.map((provider) => provider.close());
        await Promise.all(closingPromises);
    }
    async close() {
        await this.closeAllProviders();
    }
}
exports.LokiJsConnection = LokiJsConnection;
//# sourceMappingURL=LokiJsConnection.js.map