"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LokiJsMap = void 0;
/* eslint-disable @typescript-eslint/require-await */
const docdb_access_abstractions_1 = require("@js-soft/docdb-access-abstractions");
class LokiJsMap {
    collection;
    name;
    databaseType = docdb_access_abstractions_1.DatabaseType.LokiJs;
    _map;
    constructor(collection) {
        this.collection = collection;
        this.collection = collection;
        this.name = collection.name;
    }
    async set(name, value) {
        if (typeof this._map === "undefined") {
            await this.initMap();
        }
        if (typeof value.toJSON === "function") {
            value = value.toJSON();
        }
        const current = this._map.get(name);
        this._map.set(name, { name: name, value: value });
        const document = this.collection.chain().find({ name: name }).limit(1).data();
        if (!current || document.length === 0) {
            this.collection.insert({ name: name, value: value });
        }
        else {
            this.collection.update({
                $loki: document[0].$loki,
                meta: document[0].meta,
                name: name,
                value: value
            });
        }
    }
    async get(name) {
        if (typeof this._map === "undefined") {
            await this.initMap();
        }
        const document = this._map.get(name);
        if (typeof document !== "undefined") {
            return document.value;
        }
        return null;
    }
    async delete(name) {
        if (!this._map.has(name)) {
            return false;
        }
        this._map.delete(name);
        this.collection.chain().find({ name: name }).remove();
        return true;
    }
    async initMap() {
        const items = new Map();
        const results = await this.list();
        for (const item of results) {
            items.set(item.name, { name: item.name, meta: item.meta, $loki: item.$loki, value: item.value });
        }
        this._map = items;
        return items;
    }
    async find(regex) {
        return this.collection.find({ name: { $regex: regex } });
    }
    async list() {
        return this.collection.chain().data();
    }
}
exports.LokiJsMap = LokiJsMap;
//# sourceMappingURL=LokiJsMap.js.map